import 'package:equatable/equatable.dart';

abstract class CommentState extends Equatable {
  const CommentState();

  @override
  List<Object> get props => [];
}

class CommentInitial extends CommentState {}

class CommentSubmitting extends CommentState {}

class CommentSubmissionSuccess extends CommentState {}

class CommentSubmissionFailure extends CommentState {
  final String error;

  const CommentSubmissionFailure(this.error);

  @override
  List<Object> get props => [error];
}